==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicScrollBarUI__24TrackListener.h <==
// public class javax.swing.plaf.basic.BasicScrollBarUI$TrackListener

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 98edb18c5d0facd javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener

// header file dependencies
// @dep_header java_awt_event_MouseAdapter

#include "java/awt/event/MouseAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener_H_
#define _JC_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_refs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$refs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$nonrefs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vmethods	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtable	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtype	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method$_init$5dc65915419aac46(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method$mouseDragged$3079e58fafa0fefe(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method$mouseMoved$9e3a895f548fc637(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern jboolean _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method$shouldScroll$8c621e37e5f07ee3(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method_info$mouseDragged$3079e58fafa0fefe;
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method_info$mouseMoved$9e3a895f548fc637;
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method_info$mouseReleased$47ad6ad312932c8e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method_info$shouldScroll$8c621e37e5f07ee3;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vmethods {
	void	(*mouseDragged$3079e58fafa0fefe)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseMoved$9e3a895f548fc637)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
	jboolean	(*shouldScroll$8c621e37e5f07ee3)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vmethods	javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$refs {
    _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_refs	javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener;
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_nonrefs {
	jint	currentMouseX;
	jint	currentMouseY;
	jint	offset;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
    _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_nonrefs	javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object {
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtype _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicScrollBarUI__24TrackListener.h <==
// public class javax.swing.plaf.basic.BasicScrollBarUI$TrackListener

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7e7c39888aec0146 javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener

// header file dependencies
// @dep_header java_awt_event_MouseAdapter

#include "java/awt/event/MouseAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener_H_
#define _JC_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_refs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$refs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$nonrefs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vmethods	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtable	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtype	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method$_init$5dc65915419aac46(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method$mouseDragged$3079e58fafa0fefe(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method$mouseMoved$9e3a895f548fc637(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method$shouldScroll$8c621e37e5f07ee3(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method_info$mouseDragged$3079e58fafa0fefe;
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method_info$mouseMoved$9e3a895f548fc637;
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method_info$mouseReleased$47ad6ad312932c8e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$method_info$shouldScroll$8c621e37e5f07ee3;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vmethods {
	void	(*mouseDragged$3079e58fafa0fefe)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseMoved$9e3a895f548fc637)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*shouldScroll$8c621e37e5f07ee3)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vmethods	javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$refs {
    _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_refs	javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener;
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_nonrefs {
	jint	currentMouseX;
	jint	currentMouseY;
	jint	offset;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
    _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$sub_nonrefs	javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$object {
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$vtype _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicScrollBarUI__24TrackListener_H_ */
